
import rasterio as rio
import rasterio.warp
from rasterio.coords import BoundingBox
from affine import Affine


__version__ = '0.0.2'


def clip(srcpath, tarpath, dstpath):
    """
    Clip the target image to the extent of the source image.
    """
    
    with rio.drivers():
        
        with rio.open(srcpath, 'r') as src:
            srcmeta = src.meta.copy()
            srcbounds = src.bounds
        
        with rio.open(tarpath, 'r') as tar:
            tarmeta = tar.meta.copy()
            
            # Update the bounds if projections do not match
            if src.crs != tar.crs:
                x, y = srcbounds[0::2], srcbounds[1::2]
                bounds = rasterio.warp.transform(src.crs, tar.crs, x, y)
                bounds = [ point for axis in bounds for point in axis ]
                keys = ['left', 'right', 'bottom', 'top']
                srcbounds = BoundingBox(**dict(zip(keys, bounds)))
            
            window = tar.window(*srcbounds)
            count = tarmeta["count"]
            taraff = tar.affine
            
            height = window[0][1] - window[0][0]
            width = window[1][1] - window[1][0]
            tarmeta.update(width=width, height=height)
            
            with rio.open(dstpath, 'w', **tarmeta) as dst:
                
                dst.transform = Affine(taraff.a, taraff.b, srcbounds.top, taraff.d, taraff.e, srcbounds.left)
                
                for bidx in range(1, count + 1):
                    band = tar.read(bidx, window=window)
                    dst.write_band(bidx, band)


from codecs import open as codecs_open
from setuptools import setup, find_packages


# Parse the version from the fiona module.
with open('rioclip/__init__.py') as f:
    for line in f:
        if line.find("__version__") >= 0:
            version = line.split("=")[1].strip()
            version = version.strip('"')
            version = version.strip("'")
            break

# Get the long description from the relevant file
with codecs_open('README.rst', encoding='utf-8') as f:
    long_description = f.read()


setup(name='rio-clip',
      version=version,
      description=u"Clip a geo-aware raster to the bounds of another.",
      long_description=long_description,
      classifiers=[],
      keywords='',
      author=u"Amit Kapadia",
      author_email='akapad@gmail.com',
      url='https://github.com/kapadia/rio-clip',
      license='MIT',
      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'click',
          'rasterio>=0.24'
      ],
      extras_require={
          'test': ['pytest'],
      },
      entry_points="""
      [rasterio.rio_commands]
      clip=rioclip.scripts.cli:cli
      """)





import click
import rasterio
from rasterio.rio.cli import cli

from rioclip import clip as rioclip
from rioclip import __version__ as rioclip_version


@cli.command(short_help="Clip a dataset to the bounds of another dataset.")
@click.argument('srcpath', type=click.Path(resolve_path=True), required=True, metavar='SRC')
@click.argument('tarpath', type=click.Path(resolve_path=True), required=True, metavar='TAR')
@click.argument('dstpath', type=click.Path(resolve_path=False), required=True, metavar='DST')
@click.version_option(version=rioclip_version, message='%(version)s')
@click.pass_context
def clip(ctx, srcpath, tarpath, dstpath):

    verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
    rioclip(srcpath, tarpath, dstpath)